Enum trust_dns::op::OpCode
[−]
[src]
pub enum OpCode {
Query,
Status,
Notify,
Update,
}Operation code for queries, updates, and responses
RFC 1035, DOMAIN NAMES - IMPLEMENTATION AND SPECIFICATION, November 1987
OPCODE A four bit field that specifies kind of query in this
message. This value is set by the originator of a query
and copied into the response. The values are:
0 a standard query (QUERY)
1 an inverse query (IQUERY)
2 a server status request (STATUS)
3-15 reserved for future use
Variants
QueryQuery request RFC 1035
StatusStatus message RFC 1035
NotifyNotify of change RFC 1996
UpdateUpdate message RFC 2136
Methods
impl OpCode[src]
Convert from u8 to OpCode
use std::convert::From; use trust_dns_proto::op::op_code::OpCode; let var: OpCode = OpCode::from_u8(0).unwrap(); assert_eq!(OpCode::Query, var);