Enum trust_dns::serialize::binary::EncodeMode
[−]
[src]
pub enum EncodeMode {
Signing,
Normal,
}In the Verify mode there maybe some things which are encoded differently, e.g. SIG0 records should not be included in the additional count and not in the encoded data when in Verify
Variants
SigningNormalTrait Implementations
impl PartialEq for EncodeMode[src]
fn eq(&self, __arg_0: &EncodeMode) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for EncodeMode[src]
impl Clone for EncodeMode[src]
fn clone(&self) -> EncodeMode
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more